def add_numbers(num1, num2):
    return num1 + num2

def div_numbers(num1,num2):
    if num2 == 0:
        raise ValueError("Division by zero is not allowed.")
    return num1 // num2

def sub_number(num1,num2):
    return num1 - num2

def mul_number(num1,num2):
    return num1 * num2

def squ_number(num1):
    return num1 * num1
    
